<?php

/**
 * @file
 * Rules integration for taxonomy conditions.
 */

/**
 * Handles the commerce order conditions.
 * 
 * Handles the commerce order conditions by checking the order for certain 
 * taxomomy terms.
 * 
 * @param object $order 
 *   Commerce order object
 * @param string $field_name 
 *   the name of the taxonomy vocabularies
 * @param int $term_id 
 *   the taxonomy term id
 * @param string $operator 
 *   '<', '<=', '=', '>=','>'
 * @param int $value 
 *   the value that is given for the $operator to use to compare with
 * 
 * @return bool
 *   returns TRUE if value is positive to descripted rule, 
 *   FALSE if there is no match to set properties
 */
function commerce_taxonomy_conditions_rules_contains_product($order, $field_name, $term_id, $operator, $value) {
  $products = array($term_id => 0);

  // If we actually received a valid order...
  if (!empty($order) && !empty($field_name) && !empty($term_id)) {
    $order_wrapper = entity_metadata_wrapper('commerce_order', $order);

    // Run through the order to check on the taxonomy term that was given.
    foreach ($order_wrapper->commerce_line_items as $delta => $line_item_wrapper) {

      if (!empty($line_item_wrapper->commerce_product)) {
        $obj_term = $line_item_wrapper->commerce_product->$field_name->value();

        if ($obj_term->tid == $term_id) {
          // If taxonomy was found we need to add the quantity.
          $quantity = $line_item_wrapper->quantity->value();
          if (empty($products[$term_id])) {
            $products[$term_id] = $quantity;
          }
          else {
            $products[$term_id] += $quantity;
          }
        }
      }
    }

  }

  // Make a quantity comparison based on the operator.
  switch ($operator) {
    case '<':
      return $products[$term_id] < $value;

    case '<=':
      return $products[$term_id] <= $value;

    case '=':
      return $products[$term_id] == $value;

    case '>=':
      return $products[$term_id] >= $value;

    case '>':
      return $products[$term_id] > $value;

  }

  return FALSE;
}

/**
 * Get taxonomy vocabularies.
 * 
 * @return array
 *   options list of available vocabs
 */
function commerce_taxonomy_conditions_term_list() {
  $field_options_list = array();
  $fields = field_read_fields(array('type' => 'taxonomy_term_reference'));
  if (!empty($fields)) {
    foreach ($fields as $key => $value) {
      $field_options_list[$key] = $key;
    }
  }
  return $field_options_list;
}

/**
 * Get taxonomy term list based on the given vocabulary name.
 * 
 * @param string $field_name
 *   The name of the taxonomy vocab as field name
 * 
 * @return array
 *   Returns a list of available terms of the chosen vocab.
 */
function commerce_taxonomy_conditions_term_options_list($field_name = NULL) {
  $term_list = array('' => t('Choose a term'));
  if (!empty($field_name)) {
    $field = field_read_field($field_name);
    $vocabulary = taxonomy_vocabulary_machine_name_load($field['settings']['allowed_values'][0]['vocabulary']);
    if (!empty($vocabulary)) {
      $terms = taxonomy_get_tree($vocabulary->vid);

      if (!empty($terms)) {
        foreach ($terms as $term) {
          $term_list[$term->tid] = str_repeat('-', $term->depth) . $term->name;
        }
      }
    }
  }
  return $term_list;
}

/**
 * Function for the ajax call to retrieve the list taxonomy terms.
 * 
 * @param array $form
 *   standard drupal form array
 * @param array $form_state
 *   standard drupal form_state
 * 
 * @return array
 *   Returns form field select box with options based on the chosen vocab.
 */
function commerce_taxonomy_conditions_term_options_list_form($form, $form_state) {
  $terms = commerce_taxonomy_conditions_term_options_list($form_state['values']['parameter']['term_field_names']['settings']['term_field_names']);
  $form['parameter']['term_ids']['settings']['term_ids']['#options'] = $terms;
  return $form['parameter']['term_ids']['settings']['term_ids'];
}
